@@ -21,8 +21,8 @@ rm -Rf /dev/socket
 mkdir -p /dev/socket $LXC_ROOTFS_PATH/socket
 mount -n -o bind,rw /dev/socket $LXC_ROOTFS_PATH/socket
 
-# Disable adbd
-rm $LXC_ROOTFS_PATH/sbin/adbd
+# Make sure adbd is not started automatically
+sed -i 's/setprop persist.sys.usb.config adb$/setprop persist.sys.usb.config ""/' $LXC_ROOTFS_PATH/init.rc
 
 # Make sure the ubuntu_chroot init service does not get started
 sed -i '/ubuntu_chroot init$/,+2d' $LXC_ROOTFS_PATH/init.rc
